#
# spec file for package rmt-server
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define app_dir      %{_datadir}/rmt
%define lib_dir      %{_libdir}/rmt
%define data_dir     %{_localstatedir}/lib/rmt
%define conf_dir     %{_sysconfdir}/rmt
%define script_dir   %{_libexecdir}/rmt
%define rmt_user     _rmt
%define rmt_group    nginx

# Only build for the distribution default Ruby version
%define rb_build_versions     %{rb_default_ruby}
%define rb_build_ruby_abis    %{rb_default_ruby_abi}
%define ruby_version          %{rb_default_ruby_suffix}

Name:           rmt-server
Version:        2.10
Release:        150400.3.9.1
Summary:        Repository mirroring tool and registration proxy for SCC
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Proxy
URL:            https://software.opensuse.org/package/rmt-server
Source0:        %{name}-%{version}.tar.bz2
Source1:        rmt-server-rpmlintrc
Source2:        rmt.conf
Source3:        rmt-cli.8.gz
BuildRequires:  %{ruby_version}
BuildRequires:  %{ruby_version}-devel
BuildRequires:  %{ruby_version}-rubygem-bundler
BuildRequires:  chrpath
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  libcurl-devel
BuildRequires:  libffi-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  pkgconfig(systemd)
Requires:       gpg2
Recommends:     mariadb
Recommends:     nginx
# The config is not really required by rmt-server, but by nginx ...
Requires:       rmt-server-configuration
Requires(post): %{ruby_version}
Requires:       %{ruby_version}-rubygem-bundler
Requires(pre):  shadow
Requires(post): timezone
Requires(post): util-linux
Conflicts:      yast2-rmt < 1.0.3
Recommends:     rmt-server-config
Recommends:     yast2-rmt >= 1.3.0
# Does not build for i586 and s390 and is not supported on those architectures
ExcludeArch:    %{ix86} s390
%{systemd_ordering}

%description
This package provides a mirroring tool for RPM repositories and a registration
proxy for the SUSE Customer Center (SCC).

As registration is required for SUSE products, the registration proxy allows
one to register SUSE products within a private network.

It's possible to mirror SUSE, as well as openSUSE and other RPM repositories.
SCC organization credentials are required to synchronize SUSE products,
subscription information, and to mirror SUSE repositories.

RMT supersedes the main functionality of SMT in SLES 15.

%package config
Summary:        RMT default configuration
Group:          Productivity/Networking/Web/Proxy
Requires:       rmt-server = %version
Provides:       rmt-server-configuration
Conflicts:      rmt-server-configuration

%description config
Default nginx configuration for RMT.

%package pubcloud
Summary:        RMT pubcloud extensions
Group:          Productivity/Networking/Web/Proxy
Requires:       rmt-server = %version
Provides:       rmt-server-configuration
Conflicts:      rmt-server-configuration

%description pubcloud
This package extends the basic RMT functionality with capabilities
required for public cloud environments.

%prep
cp -p %{SOURCE2} .

%setup -q
sed -i '1 s|/usr/bin/env\ ruby|/usr/bin/ruby.%{ruby_version}|' bin/*

%build
bundle.%{ruby_version} config build.nio4r --with-cflags='%{optflags} -Wno-return-type'
bundle.%{ruby_version} config set deployment 'true'
bundle.%{ruby_version} config set without 'test development'
bundle.%{ruby_version} install %{?jobs:--jobs %{jobs}}

%install
mkdir -p %{buildroot}%{data_dir}
mkdir -p %{buildroot}%{lib_dir}
mkdir -p %{buildroot}%{app_dir}
mkdir -p %{buildroot}%{conf_dir}/ssl
mkdir -p %{buildroot}%{data_dir}/regsharing

mv tmp %{buildroot}%{data_dir}
mkdir %{buildroot}%{data_dir}/public
mv public/repo %{buildroot}%{data_dir}/public/
mv public/suma %{buildroot}%{data_dir}/public/
mv vendor %{buildroot}%{lib_dir}

cp -ar . %{buildroot}%{app_dir}
ln -s %{data_dir}/tmp %{buildroot}%{app_dir}/tmp
mkdir -p %{buildroot}%{_bindir}
ln -s %{app_dir}/bin/rmt-cli %{buildroot}%{_bindir}
ln -s %{app_dir}/bin/rmt-data-import %{buildroot}%{_bindir}/rmt-data-import
ln -s %{app_dir}/bin/rmt-test-regsharing %{buildroot}%{_bindir}
ln -s %{app_dir}/bin/rmt-manual-instance-verify %{buildroot}%{_bindir}
install -D -m 644 %{_sourcedir}/rmt-cli.8.gz %{buildroot}%{_mandir}/man8/rmt-cli.8.gz

# systemd
mkdir -p %{buildroot}%{_unitdir}

install -m 444 package/files/systemd/rmt-server-mirror.timer %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-sync.timer %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-systems-scc-sync.timer %{buildroot}%{_unitdir}

install -m 444 package/files/systemd/rmt-server-mirror.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-sync.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-systems-scc-sync.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server.target %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-migration.service %{buildroot}%{_unitdir}

install -m 444 engines/registration_sharing/package/rmt-server-regsharing.service %{buildroot}%{_unitdir}
install -m 444 engines/registration_sharing/package/rmt-server-regsharing.timer %{buildroot}%{_unitdir}
install -m 444 engines/registration_sharing/package/rmt-server-trim-cache.service %{buildroot}%{_unitdir}
install -m 444 engines/registration_sharing/package/rmt-server-trim-cache.timer %{buildroot}%{_unitdir}

mkdir -p %{buildroot}%{_sbindir}
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-migration
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-mirror
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-sync
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-systems-scc-sync

ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-regsharing
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-trim-cache

ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-regsharing
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-trim-cache

mkdir -p %{buildroot}%{_sysconfdir}
mv %{_builddir}/rmt.conf %{buildroot}%{_sysconfdir}/rmt.conf

# nginx
install -D -m 644 package/files/nginx/nginx-http.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-http.conf
install -D -m 644 package/files/nginx/nginx-https.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-https.conf

install -D -m 644 package/files/nginx-pubcloud/nginx-http.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-http.conf
install -D -m 644 package/files/nginx-pubcloud/nginx-https.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-https.conf
install -D -m 644 package/files/nginx-pubcloud/auth-handler.conf %{buildroot}%{_sysconfdir}/nginx/rmt-auth.d/auth-handler.conf
install -D -m 644 package/files/nginx-pubcloud/auth-location.conf %{buildroot}%{_sysconfdir}/nginx/rmt-auth.d/auth-location.conf

sed -i -e '/BUNDLE_PATH: .*/cBUNDLE_PATH: "\/usr\/lib64\/rmt\/vendor\/bundle\/"' \
    -e 's/^BUNDLE_JOBS: .*/BUNDLE_JOBS: "1"/' \
    %{buildroot}%{app_dir}/.bundle/config

# supportconfig plugin
mkdir -p %{buildroot}%{_libexecdir}/supportconfig/plugins
install -D -m 544 support/rmt %{buildroot}%{_libexecdir}/supportconfig/plugins/rmt

# Directory permission update script
mkdir -p %{buildroot}%{script_dir}
install -D -m 544 package/files/update_rmt_app_dir_permissions.sh %{buildroot}%{script_dir}/update_rmt_app_dir_permissions.sh

# bash completion
install -D -m 644 package/files/rmt-cli_bash-completion.sh %{buildroot}%{_datadir}/bash-completion/completions/rmt-cli

install -D -m 644 package/files/rmt-server.reg %{buildroot}%{_sysconfdir}/slp.reg.d/rmt-server.reg

# cleanup of /usr/bin/env commands
grep -rl '\/usr\/bin\/env ruby' %{buildroot}%{lib_dir}/vendor/bundle/ruby | xargs \
    sed -i -e 's@\/usr\/bin\/env ruby.%{ruby_version}@\/usr\/bin\/ruby\.%{ruby_version}@g' \
    -e 's@\/usr\/bin\/env ruby@\/usr\/bin\/ruby\.%{ruby_version}@g'
grep -rl '\/usr\/bin\/env bash' %{buildroot}%{lib_dir}/vendor/bundle/ruby | xargs \
    sed -i -e 's@\/usr\/bin\/env bash@\/bin\/bash@g'

# Drop 'BUNDLED WITH' line from Gemfile.lock. It causes trouble when the Gemfile.lock
# was created with a different major version than the distribution's bundler.
sed -i '/BUNDLED WITH/{N;d;}' %{buildroot}%{app_dir}/Gemfile.lock

# cleanup unneeded files
find %{buildroot}%{lib_dir} "(" -name "*.c" -o -name "*.h" -o -name .keep ")" -delete
find %{buildroot}%{app_dir} -name .keep -delete
find %{buildroot}%{data_dir} -name .keep -delete
rm -r  %{buildroot}%{lib_dir}/vendor/bundle/ruby/[23].*.0/cache
rm -rf %{buildroot}%{lib_dir}/vendor/cache
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/doc
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/examples
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/samples
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/test
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/ports
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/ext
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/bin
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/spec
rm -f %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/.gitignore
rm -f %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/extensions/*/*/*/gem_make.out
rm -f %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/extensions/*/*/*/mkmf.log
find %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/yard*/ -type f -exec chmod 644 -- {} +

%fdupes %{buildroot}/%{lib_dir}

# drop custom rpath from native gems
chrpath -d %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/mysql2-*/lib/mysql2/mysql2.so
chrpath -d %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/extensions/*/*/mysql2-*/mysql2/mysql2.so

%files
%attr(0755,root,root) %{app_dir}
%exclude %{app_dir}/engines/
%exclude %{app_dir}/package/
%exclude %{app_dir}/rmt/tmp
%attr(-,%{rmt_user},%{rmt_group}) %{data_dir}
%attr(-,%{rmt_user},%{rmt_group}) %{conf_dir}
%dir %{_libexecdir}/supportconfig
%dir %{_libexecdir}/supportconfig/plugins
%dir %{script_dir}
%dir /var/lib/rmt
%ghost %{_datadir}/rmt/public/repo
%ghost %{_datadir}/rmt/public/suma
%dir %{_sysconfdir}/slp.reg.d
%config(noreplace) %attr(0640, %{rmt_user}, root) %{_sysconfdir}/rmt.conf
%config(noreplace) %{_sysconfdir}/slp.reg.d/rmt-server.reg
%{_mandir}/man8/rmt-cli.8%{?ext_man}
%{_bindir}/rmt-cli
%{_bindir}/rmt-data-import
%{_sbindir}/rcrmt-server
%{_sbindir}/rcrmt-server-migration
%{_sbindir}/rcrmt-server-sync
%{_sbindir}/rcrmt-server-mirror
%{_sbindir}/rcrmt-server-systems-scc-sync
%{_unitdir}/rmt-server.target
%{_unitdir}/rmt-server.service
%{_unitdir}/rmt-server-migration.service
%{_unitdir}/rmt-server-mirror.service
%{_unitdir}/rmt-server-mirror.timer
%{_unitdir}/rmt-server-sync.service
%{_unitdir}/rmt-server-sync.timer
%{_unitdir}/rmt-server-systems-scc-sync.service
%{_unitdir}/rmt-server-systems-scc-sync.timer
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/rmt-cli

%{_libdir}/rmt
%{_libexecdir}/supportconfig/plugins/rmt
%{script_dir}/update_rmt_app_dir_permissions.sh

%files config
%dir %{_sysconfdir}/nginx
%dir %{_sysconfdir}/nginx/vhosts.d
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-http.conf
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-https.conf

%files pubcloud
%{_bindir}/rmt-test-regsharing
%{_bindir}/rmt-manual-instance-verify
%attr(-,root,root) %{app_dir}/engines/
%dir %{_sysconfdir}/nginx/rmt-auth.d/
%dir %attr(-,%{rmt_user},%{rmt_group}) %{data_dir}/regsharing
%exclude %{app_dir}/engines/registration_sharing/package/
%dir %{_sysconfdir}/nginx
%dir %{_sysconfdir}/nginx/vhosts.d
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-http.conf
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-https.conf
%config(noreplace) %{_sysconfdir}/nginx/rmt-auth.d/auth-handler.conf
%config(noreplace) %{_sysconfdir}/nginx/rmt-auth.d/auth-location.conf

%{_sbindir}/rcrmt-server-regsharing
%{_sbindir}/rcrmt-server-trim-cache
%{_unitdir}/rmt-server-regsharing.service
%{_unitdir}/rmt-server-regsharing.timer
%{_unitdir}/rmt-server-trim-cache.service
%{_unitdir}/rmt-server-trim-cache.timer

%pre
getent group %{rmt_group} >/dev/null || %{_sbindir}/groupadd -r %{rmt_group}
getent passwd %{rmt_user} >/dev/null || \
	%{_sbindir}/useradd -g %{rmt_group} -s /bin/false -r \
	-c "user for RMT" %{rmt_user}
%service_add_pre rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service rmt-server-systems-scc-sync.service

%post
%service_add_post rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service rmt-server-systems-scc-sync.service
cd %{_datadir}/rmt && bin/rails rmt:secrets:create_encryption_key >/dev/null RAILS_ENV=production && \
cd %{_datadir}/rmt && bin/rails rmt:secrets:create_secret_key_base >/dev/null RAILS_ENV=production && \
# Run only on install
if [ $1 -eq 1 ]; then
  echo "Please run the YaST RMT module (or 'yast2 rmt' from the command line) to complete the configuration of your RMT" >> /dev/stdout
fi

# Run only on upgrade
if [ $1 -eq 2 ]; then
  if [ -f %{app_dir}/ssl/rmt-ca.crt ]; then
    mv %{app_dir}/ssl/* %{conf_dir}/ssl
    echo "RMT SSL configuration has been moved to a new location: %{conf_dir}/ssl"
  fi
  if [ -f %{app_dir}/config/system_uuid ]; then
    mv %{app_dir}/config/system_uuid /var/lib/rmt/system_uuid
  fi
  bash %{script_dir}/update_rmt_app_dir_permissions.sh %{app_dir}
fi

if [ ! -e %{_datadir}/rmt/public/repo ]; then
 ln -ns %{_sharedstatedir}/rmt/public/repo %{_datadir}/rmt/public/repo
fi

if [ ! -e %{_datadir}/rmt/public/suma ]; then
 ln -ns %{_sharedstatedir}/rmt/public/suma %{_datadir}/rmt/public/suma
fi

%preun
%service_del_preun rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service rmt-server-systems-scc-sync.service

%postun
%service_del_postun rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service rmt-server-systems-scc-sync.service

%posttrans config
# Don't fail if either systemd or nginx are not running
/usr/bin/systemctl try-reload-or-restart nginx.service || true

%pre pubcloud
%service_add_pre rmt-server-regsharing.service rmt-server-trim-cache.service

%post pubcloud
%service_add_post rmt-server-regsharing.service rmt-server-trim-cache.service

%preun pubcloud
%service_del_preun rmt-server-regsharing.service rmt-server-trim-cache.service

%postun pubcloud
%service_del_postun rmt-server-regsharing.service rmt-server-trim-cache.service

%posttrans pubcloud
/usr/bin/systemctl try-restart rmt-server.service
/usr/bin/systemctl reload nginx.service

%changelog
* Fri Nov 11 2022 tschmidt@suse.com
- Release version 2.10:
  - Add option to turn off system token support (bsc#1205089)
  - Update the `last_seen_at` column on zypper service refresh
  - Do not retry to import non-existing files in air-gapped mode (bsc#1204769)
  - Fix CVE-2022-31254 (bsc#1204285): rmt-server-pubcloud allows to escalate from user _rmt to root
  Root-level escalation vector bug was found in the packaging file which has been mitigated.
* Tue Nov  8 2022 zpetrova@suse.com
- adapt rmt-client-setup-res script to work on SLL9/RHEL9
* Thu Sep 22 2022 fschnizlein@suse.com
- Send system creation and product activation dates to SCC for better
  visibility in SCC.
* Fri Sep  2 2022 tschmidt@suse.com
- Release version 2.9: Implement `System-Token` header handling to improve unique system reporting.
* Wed Jul 20 2022 jesus.bv@suse.com
- Add --proxy-byos flag to rmt-cli systems command to filter
  BYOS systems using RMT as a proxy
* Fri Jul  1 2022 tschmidt@suse.com
- Version 2.8.1:
  Retry failed http requests automatically (bsc#1197405, bsc#1188578, bsc#1198721, bsc#1199961)
* Mon May  2 2022 tschmidt@suse.com
- Improved rmt-client-setup-res script for CentOS8.x and RHEL/RES8.x (bsc#1197038)
* Mon Mar 14 2022 fschnizlein@suse.com
- Version 2.8.0
- Forwarding information of registered systems to SCC more efficiently in batches
- Syncing the systems' most recent last seen timestamps to SCC
* Mon Mar  7 2022 fschnizlein@suse.com
- Optional '--no-confirmation' switch to skip user confirmation when cleaning repository data
* Thu Mar  3 2022 tschmidt@suse.com
- Fix "rmt-cli systems list --csv -a" for RMTs with millions of systems (bsc#1191552)
* Thu Feb 17 2022 jmason@suse.com
- Enable nginx configs to serve on IPv6
- Enable users with old versions of RMT to sync systems with SCC by default
* Mon Jan 31 2022 dimstar@opensuse.org
- Fix build using ruby 3.x (boo#1195318).
* Thu Jan 27 2022 ngetahun@suse.com
- Version 2.7.1
- Remove products with a negative ID during migration
- Changes to RMT/connect API: RMT returns HTTP status code 422 whenever a system
  tries to register/activate a product with an expired subscription.
- Mirror metadata retry. This fixes bsc#1188578
  PubCloud:
- Update the way allowed paths are checked
  SUMA requested a new feature where it is possible to validate
  all versions of the same product and arch (that are allowed to that system)
- De-register BYOS systems using RMT as a proxy from SCC
- De-activate a single product from a BYOS proxy system
- Add the handling of the BYOS systems that use RMT as a SCC proxy
  In order to do that:
- New boolean column in systems table in db: proxy_byos
- Skip the sync with SCC (using that column)
- Registration of the system to SCC (announce system call and
  then use SCC credentials)
- Activation of products
- Check subscription is active/valid for a product/repo to be accessed
* Thu Oct  7 2021 fschnizlein@suse.com
- Version 2.7.0
- Add subscription support in RMT. RMT can now consume registration codes
  supplied when registering a system.
- Add host's login header to API requests to SCC. If the information is
  available, RMT will send it on requests to attach the registration proxy to a
  host system in SCC.
- Add extra check to product dependency on RMT API. Now, when a system tries to
  activate a module through RMT, if it requires a root product which is not
  activated, the activation will fail (bnc#951189).
- Load global configuration only if it can be ready by the current process.
* Thu Aug 19 2021 fschnizlein@suse.com
- Version 2.6.12
- Re-fix broken symlinks: This version fixes the bug-fix
  deployed with version 2.6.11. Reference bug (bsc#1188043)
- Handle special characters in package names (bsc#1189805)
* Tue Jun 29 2021 fschnizlein@suse.com
- Version 2.6.11
- Add release_stage to all api endpoints to allow external programm determine
  product stage (bsc#1176628)
- Fix: Don't create suma and repo symlinks at install stage, instead
  only link them at the post stage if they don't exist (bsc#1188043)
- Update translations
- additional debug output for mirroring subcommand with '--debug' flag
* Fri Jun  4 2021 natnael.getahun@suse.com
- Version 2.6.10
- Fix: Rails 6.1 zeitwerk autoloading errors
  This references bsc#1186798
* Thu Apr 22 2021 jesus.bv@suse.com
- Version 2.6.9
- Fix: Store authorization tokens when adding custom repositories
- Fix: Don't append slash to custom repository urls
- Add enabled attribute to syncing process
  This fixes wrong marked repositories when syncing
  This references bsc#1184814
- Enable 'Installer-Updates' repositories when
  enabling a product, so they can get used by
  the installer to patch the installation system itself.
  This references bsc#1184814
* Mon Mar 29 2021 fschnizlein@suse.com
- Version 2.6.8
- Fixing wrong handling of ids starting with numeric characters (bsc#1182736)
* Tue Mar 16 2021 ikapelyukhin@suse.com
- Version 2.6.7
- Clean out `subscriptions` table only if replacement data is already
  available (bsc#1183615)
- Raise an error when there is an extension activated which has no
  migration successor (like LTSS)
* Tue Mar 16 2021 jmammen@suse.com
- Include installed modules to the solution tree when doing
  an offline migration. (bsc#1179523)
* Fri Feb 26 2021 jesus.bv@suse.com
- Do not raise an exception when mirroring
  if info missing is in alpha or beta stage
  This references bsc#1180018
* Thu Feb 18 2021 natnael.getahun@suse.com
- Fix rpath build issues
- Resubmit version 2.6.6
* Mon Feb 15 2021 natnael.getahun@suse.com
- Version 2.6.6
- Add filter options for product listing and bash completion for new flags
* Wed Oct  7 2020 tmuntaner@suse.com
- Version 2.6.5
- Solved potential bug of SCC repository URLs changing over time. RMT
  now self heals by removing the previous invalid repository and
  creating the correct one.
* Fri Oct  2 2020 luis.caparroz@suse.com
- Version 2.6.4
- Add web server settings to /etc/rmt.conf:
  Now it's possible to configure the minimum and maximum threads count as well
  the number of web server workers to be booted through /etc/rmt.conf.
* Wed Sep 30 2020 tmuntaner@suse.com
- Version 2.6.3
- Instead of using an MD5 of URLs for custom repository friendly_ids,
  RMT now builds an ID from the name.
* Tue Sep 29 2020 luis.caparroz@suse.com
- Version 2.6.2
- Fix RMT file caching based on timestamps:
  Previously, RMT sent GET requests with the header 'If-Modified-Since' to a
  repository server and if the response had a 304 (Not Modified), it would copy
  a file from the local cache instead of downloading. However, if the local file
  timestamp accidentally changed to a date newer than the one on the repository
  server, RMT would have an outdated file, which caused some errors.
  Now, RMT makes HEAD requests to the repositories servers and inspect the
  'Last-Modified' header to decide whether to download a file or copy it from
  cache, by comparing the equalness of timestamps.
* Tue Sep 29 2020 tmuntaner@suse.com
- Version 2.6.1
- Fixed an issue where relative paths supplied to `rmt-cli import repos`
  caused the command to fail.
* Mon Sep 21 2020 tmuntaner@suse.com
- Version 2.6.0
- Friendlier IDs for custom repositories:
  In an effort to simplify the handling of SCC and custom repositories,
  RMT now has friendly IDs. For SCC repositories, it's the same SCC ID
  as before. For custom repositories, it can either be user provided
  or RMT generated (MD5 of the provided URL).
  Benefits:
  * `rmt-cli mirror repositories` now works for custom repositories.
  * Custom repository IDs can be the same across RMT instances.
  * No more confusing "SCC ID" vs "ID" in `rmt-cli` output.
  Deprecation Warnings:
  * RMT now uses a different ID for custom repositories than before.
    RMT still supports that old ID, but it's recommended to start
    using the new ID to ensure future compatibility.
* Thu Sep 10 2020 tmuntaner@suse.com
- Version 2.5.20
- Updated rails from 6.0.3.2 to 6.0.3.3:
  - actionview (CVE-2020-15169)
* Wed Sep  9 2020 tmuntaner@suse.com
- Version 2.5.19
- RMT now has the ability to remove local systems with the command
  `rmt-cli systems remove`.
* Tue Sep  8 2020 luis.caparroz@suse.com
- Version 2.5.18
- Fixed exit code for `rmt-cli mirror` and its subcommands. Now it exits with 1
  whenever an error occurrs during mirroring
- Improved message logging for `rtm-cli mirror`. Instead of logging an error
  when it occurs, the command summarize all errors at the end of execution. Now
  log messages have colors to better identify failure/success.
* Wed Sep  2 2020 jesus.bv@suse.com
- Version 2.5.17
- RMT no longer provides the installer updates repository to systems via its
  zypper service. This repository is used during the installation process, as
  it provides an up-to-date installation experience, but it has no use on an
  already installed system.
* Tue Sep  1 2020 tmuntaner@suse.com
- Version 2.5.16
- Updated RMT's rails and puma dependencies.
  - puma (CVE-2020-11076, CVE-2020-11077, CVE-2020-5249, CVE-2020-5247
    CVE-2019-16770)
  - actionpack (CVE-2020-8185, CVE-2020-8164, CVE-2020-8166)
  - actionview (CVE-2020-8167, CVE-2020-5267, CVE-2019-5418, CVE-2019-5419)
  - activesupport (CVE-2020-8165)
  - railties (CVE-2019-5420)
* Mon Aug 31 2020 tmuntaner@suse.com
- Version 2.5.15
- RMT now checks if repositories are fully mirrored during the
  activation process. Previously, RMT only checked if the repositories
  were enabled to be mirrored, but not that they were actually mirrored.
  In this case, RMTs were not able to provide the repository data which
  systems assumed it had.
* Mon Aug 24 2020 jesus.bv@suse.com
- Version 2.5.14
- Enable 'Installer-Updates' repositories by default
* Fri Aug 21 2020 tmuntaner@suse.com
- Fixed deprecation warning when thor encountered an error. Also,
  instead of returning 0 for thor errors, rmt-cli will return 1
  instead.
* Fri Aug 14 2020 tmuntaner@suse.com
- Version 2.5.13
- Added `rmt-cli repos clean` command to remove locally mirrored files
  of repositories which are not marked to be mirrored.
- Previously, RMT didn't track deduplicated files in its database. Now,
  to accommodate `rmt-cli repos clean`, RMT will track all mirrored
  files.
* Thu Jul 30 2020 kukuk@suse.com
- Move the nginx reload to the configuration package which contain
  nginx config files, don't reload nginx unconditionally from main
  package.
* Thu Jul  9 2020 luis.caparroz@suse.com
- Version 2.5.12
- Update rack to version 2.2.3 (CVE-2020-8184: bsc#1173351)
- Update Rails to version 5.2.4.3:
  - actionpack (CVE-2020-8164: bsc#1172177)
  - actionpack (CVE-2020-8166: bsc#1172182)
  - activesupport (CVE-2020-8165: bsc#1172186)
  - actionview (CVE-2020-8167: bsc#1172184)
* Wed Jul  8 2020 ikapelyukhin@suse.com
- Version 2.5.11
- rmt-server-pubcloud:
  - SLES11 EOL
  - Extension activation verification based on the available subscriptions
  - Added a manual instance verification script
* Tue Jun 16 2020 luis.caparroz@suse.com
- Version 2.5.10
- Support rmt-server to run with Ruby 2.7 (Factory/Tumbleweed):
  - Bump gem 'config' version from 1.7.2 to 2.2.1 to fix incompatibility Ruby
    2.7 OpenStruct class;
  - Bump gem 'typhoeus' version from 1.3.1 to 1.4.0 in order to also bump gem
    'ethon' version, which caused a 'rb_safe_level' warning on Ruby 2.7;
  - Fix "last arg as keyword arg" Ruby 2.7 warning on source code;
  - Disable "deprecated" warnings from Ruby 2.7; Rails 5.1 generates a lot of
    warnings with Ruby 2.7, mainly due to "capturing the given block with
    Proc.new", which is deprecated;
  - Improve RPM spec to consider only the distribution default Ruby version
    configured in OBS;
  - Improve RPM spec to remove Ruby 2.7 warnings regarding 'bundler.
* Tue Jun  9 2020 kukuk@suse.com
- Move nginx/vhosts.d directory to correct sub-package. They
  are needed together with nginx, not rmt-server.
- Fix dependencies especially for containerized usage:
  - mariadb and nginx are not hard requires, could run on another host
- Fix generic dependencies:
  - systemd ordering was missing
  - shadow is required for pre-install
* Fri Jun  5 2020 jesus.bv@suse.com
- Set cloud_povider info when registering the instance
* Fri May 29 2020 ikapelyukhin@suse.com
- Version 2.5.9
- rmt-server-pubcloud: enforce strict authentication
* Tue May 19 2020 lcaparroz@suse.com
- Version 2.5.8
- Use repomd_parser gem to remove repository metadata parsing code.
* Fri Apr 17 2020 ikapelyukhin@suse.com
- Version 2.5.7
- Use DB locks intead of lockfiles (bsc#1165548)
* Fri Apr  3 2020 tschmidt@suse.com
- Version 2.5.6
- Align supported subscription types with SCC:
  'test', 'full', 'evaluation', 'oem', 'internal', 'partner'
  (bsc#1168554)
* Wed Feb  5 2020 fschnizlein@suse.com
- Version 2.5.5
- Add `rmt-cli products show` command to show detailed product information
* Wed Feb  5 2020 skotov@suse.com
- Version 2.5.4
- Fix migrations in case adding migration_extra column failed (bsc#1162296)
* Mon Feb  3 2020 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Tue Jan 28 2020 fschnizlein@suse.com
- Version 2.5.3
- low_speed_time and low_speed_limit can be configured
* Tue Jan 21 2020 jmammen@suse.com
- Version 2.5.2
- Fix offline migration (CVE-2019-18904: bsc#1160922)
- Ensure download of signature file from custom repositories
* Fri Jan 10 2020 ikapelyukhin@suse.com
- Version 2.5.1
- Relax systemd units dependencies (bsc#1160673)
* Wed Dec 18 2019 ikapelyukhin@suse.com
- Version 2.5.0
- Add `rmt-cli scc sync-systems` command
* Tue Dec 10 2019 ikapelyukhin@suse.com
- Version 2.4.5
- rmt-server-pubcloud: escape paths in regex
* Mon Dec  9 2019 ikapelyukhin@suse.com
- Version 2.4.4
- Verbose error reporting for SCC API errors (bsc#1157119)
* Wed Nov 13 2019 ikapelyukhin@suse.com
- Version 2.4.3
- rmt-server-pubcloud: Relax zypper auth plugin checks; produce detailed logs
- rmt-server-pubcloud: Allow access to SLES 12 SP1 repos when SLES 11 was activated
* Mon Sep 16 2019 jgomez@suse.com
- Version 2.4.2
- Fixed system listing when architecture is not well referenced
  (bsc#1141122)
- Added rmt-client-setup-res for RES8 systems
* Wed Aug 21 2019 ikapelyukhin@suse.com
- Version 2.4.1
- Preserve cached metadata timestamps (bsc#1146611)
* Tue Aug 20 2019 ikapelyukhin@suse.com
- Version 2.4.0
- Allow to mirror individual products/repositories (bsc#1138863)
* Fri Aug 16 2019 tmuntaner@suse.com
- Version 2.3.7
- RMT now uses mirror_src to determine whether or not to download
  source packages. (bsc#1145688)
* Thu Aug  8 2019 ikapelyukhin@suse.com
- Version 2.3.6
- Make Rails log level configurable; set default log level to INFO
* Wed Aug  7 2019 tschmidt@suse.com
- Version 2.3.5
- Fix RMT installer_repo call for empty release_type parameter (bsc#1136178)
* Tue Jul 30 2019 ikapelyukhin@suse.com
- Version 2.3.4
- Clean up download queue on metadata download errors (bsc#1142641)
- Fix plain HTTP PubCloud config
* Wed Jul 24 2019 lschroeder@suse.com
- Version 2.3.3
- Removed release stage from names to be consistent with SCC (bsc#1136168)
  * Generate friendly_name as needed
  * Drops friendly_name column from database
* Thu Jul 18 2019 ikapelyukhin@suse.com
- Version 2.3.2
- PubCloud nginx config improvements:
  * Proxy only the known routes to the backend
  * Disable error logging for /repo
  * Serve smt.crt over HTTPS
* Fri Jul  5 2019 ikapelyukhin@suse.com
- Version 2.3.1
- Fix mirroring logic when errors are encountered (bsc#1140492)
- Refactor RMT::Mirror to download metadata/licenses in parallel
* Mon Jul  1 2019 ikapelyukhin@suse.com
- Version 2.3.0
- Check repo metadata GPG signatures during mirroring (bsc#1132690)
- Add rmt-server-config subpackage with nginx configs (fate#327816, bsc#1136081)
* Wed Jun 26 2019 skotov@suse.com
- Version 2.2.1
- Fix dependency to removed boot_cli_i18n file (bsc#1136020)
* Fri Jun 14 2019 ikapelyukhin@suse.com
- Version 2.2.0
- Add `rmt-cli systems list` command to list registered systems
* Thu Jun  6 2019 lschroeder@suse.com
- Version 2.1.5
- Fix create UUID when system_uuid file empty (bsc#1138316)
* Wed May 15 2019 ikapelyukhin@suse.com
- Version 2.1.4
- Fix duplicate nginx location in rmt-server-pubcloud (bsc#1135222)
* Mon May 13 2019 ikapelyukhin@suse.com
- Version 2.1.3
- Mirror additional repos that were enabled during mirroring (bsc#1132690)
* Wed May  8 2019 ikapelyukhin@suse.com
- Version 2.1.2
- Make service IDs consistent across different RMT instances (bsc#1134428)
* Mon May  6 2019 ikapelyukhin@suse.com
- Version 2.1.1
- Make SMT data import scripts faster (bsc#1134190)
* Wed Apr 24 2019 tmuntaner@suse.com
- Version 2.1.0
- Updated dependency nokogiri to 1.10.3 (CVE-2019-11068: bsc#1132160)
- Allow RMT registration to work under HTTP as well as HTTPS.
* Wed Apr 17 2019 tmuntaner@suse.com
- Version 2.0.0
- Breaking Change: Added headers to generated CSV files
* Tue Apr  2 2019 skotov@suse.com
- Version 1.2.8
- Offline migration from SLE 15 to SLE 15 SP1 will add Python2 module
* Thu Mar 21 2019 skotov@suse.com
- Version 1.2.7
- Online migrations will automatically add additional modules
  to the client systems depending on the base product
* Wed Mar 20 2019 ikapelyukhin@suse.com
- Version 1.2.6
- Fix incorrect triggering of registration sharing (bsc#1129392)
- Add a script to manually test registration sharing
* Mon Mar 18 2019 tmuntaner@suse.com
- Version 1.2.5
- Updated rails to version 5.1.6.2 (CVE-2019-5419: bsc#1129271)
* Wed Mar 13 2019 ikapelyukhin@suse.com
- Version 1.2.4
- Supply log severity to journald
* Tue Mar 12 2019 hschmidt@suse.com
- Version 1.2.3
- Fix license mirroring issue in some non-SUSE repositories (bsc#1128858)
* Mon Mar 11 2019 tmuntaner@suse.com
- Added the ability to mirror the SUMA product tree.
* Thu Feb 21 2019 ikapelyukhin@suse.com
- Version 1.2.2
- Set CURLOPT_LOW_SPEED_LIMIT to prevent downloads from getting stuck (bsc#1107806)
- Removed use-ruby-2.5-in-rails.patch, use-ruby-2.5-in-rmt-data-import.patch and
  use-ruby-2.5-in-rmt-cli.patch as they are no longer needed.
* Mon Feb 18 2019 skotov@suse.com
- Version 1.2.1
- Truncate the RMT lockfile when writing a new PID (bsc#1125770)
- Zypper authentication plugin (fate#326629)
- Fix nested serializers in system/activations
- Fix HTTP vhost config
* Wed Jan 30 2019 ikapelyukhin@suse.com
- Version 1.2.0
- Legacy zypper XML endpoint for backward compatibility
  with SMT (fate#326629)
- Instance verification plugin in rmt-server-pubcloud (fate#326629)
* Tue Jan 22 2019 fschnizlein@suse.com
- Version 1.1.3
- Fix missing trailing slashes on custom repository import from SMT
  (bsc#1118745)
* Fri Jan 18 2019 skotov@suse.com
- Version 1.1.2
- Fix product version display (bsc#1117722)
* Tue Jan 15 2019 hschmidt@suse.com
- Cut version 1.1.1
* Tue Jan  8 2019 hschmidt@suse.com
- Fix some migration problems which caused some extensions / modules
  to be dropped. (bsc#1118584, bsc#1118579)
* Tue Dec 11 2018 tmuntaner@suse.com
- Fix listing of enabled for mirroring for non-mirrored products. (bsc#1102193)
* Tue Dec 11 2018 skotov@suse.com
- Include online migration paths into offline migration (bsc#1117106)
* Tue Dec 11 2018 skotov@suse.com
- Sync products that do not have base product (bsc#1109307)
* Fri Dec  7 2018 tmuntaner@suse.com
- Repository table using context relevant values instead of true and
  false.
* Thu Dec  6 2018 tmuntaner@suse.com
- Version 1.1.0
* Wed Dec  5 2018 tmuntaner@suse.com
- Bugfix: Alias commands in short form no longer raise an exception
  * remove -> rm -> r
  * list -> ls -> l
* Mon Dec  3 2018 tmuntaner@suse.com
- Added ability to enable/disable multiple repositories at the
  same time.
* Mon Dec  3 2018 tmuntaner@suse.com
- The command `rmt-cli products list` is more compact for smaller
  screens.
* Thu Nov 22 2018 hschmidt@suse.com
- Remove the "No product license found" message when mirroring.
  It's not useful for users, and it was just causing confusion,
  as many people mistook it for an error.
* Thu Nov 22 2018 wstephenson@suse.com
- Register to SLP if a server running on this host (bsc#1113760)
* Wed Nov 21 2018 skotov@suse.com
- Modules for migration are being sorted in the correct order
* Tue Nov 20 2018 tmuntaner@suse.com
- Added the ability to localize RMT
* Fri Nov  9 2018 sschricker@suse.de
- Add bash completion for rmt-cli
* Thu Nov  8 2018 tmuntaner@suse.com
- Added ability to enable/disable multiple products at the same time
* Tue Oct 30 2018 skotov@suse.com
- Version 1.0.7
- Import migration_extra attribute from SCC API
- Offline migrations will automatically add additional modules
  to the client systems depending on the base product
- Dependency gems security updates:
  - Update loofah to 2.2.3 (CVE-2018-16468)
  - Update rack to 2.0.6 (CVE-2018-16470)
  - Update nokogiri to 1.8.5 (CVE-2018-14404)
* Tue Oct 30 2018 tmuntaner@suse.com
- Added flag `--all-modules` to the `products enable` command to
  enable all free modules/extensions.
* Thu Sep 27 2018 ikapelyukhin@suse.com
- Improved exception handling when HTTP request fails due to
  a network or SSL validity issue
* Thu Aug  2 2018 fschnizlein@suse.com
- Version 1.0.6
- Change file paths to new locations to make RMT work with
  read-only rootfs (bsc#1102198)
- Change file permissions for rmt.conf (bsc#1104232)
- Nginx forwards to IPv4 address only (bsc#1107100)
* Thu Jul 19 2018 wstephenson@suse.com
- Version 1.0.5
- sort all list outputs alphabetically (bsc#1088680)
- Include 'last_seen_at' field in API systems output, for
  consistency with SCC
* Wed Jul  4 2018 fschueller@suse.com
- Version 1.0.4
- Only show post-install message on initial install
* Wed Jun 27 2018 ikapelyukhin@suse.com
- Version 1.0.3
- Fix duplicate migration paths (bsc#1097824)
* Tue Jun 19 2018 ikapelyukhin@suse.com
- Version 1.0.2
- Improved handling of errors during mirroring (bsc#1096967)
- Set correct permissions for product.license directory (bsc#1097367)
- Log version on service startup
* Fri Jun  1 2018 wstephenson@suse.com
- Version 1.0.1
- Use curl instead of wget in rmt-client-setup (bsc#1094348)
* Fri May 18 2018 skotov@suse.com
- Bump version to 1.0.0 (bsc#1093879)
- Make rmt-server recommend yast2-rmt
- Add the post-install message about running yast2-rmt
- Add new script rmt-data-import for migration from SMT to RMT
- Split off usage instruction into MANUAL.md
- Squash migrations into one
- Small improvements on CLI responses
- Rename clientSetup4RMT.sh => rmt-client-setup
- Add use-ruby-2.5-in-rmt-data-import.patch
* Fri May 11 2018 hschmidt@suse.com
- Don't check if a product has repos and that they are mirrored
  when deactivating.
  See: https://github.com/SUSE/rmt/pull/168
* Wed May  9 2018 wstephenson@suse.com
- Show custom repositories and product bindings in supportconfig
  plugin output
- Add CSV output option
  See: https://github.com/SUSE/rmt/pull/158
* Tue May  8 2018 tmuntaner@suse.com
- Rename of service files
  rmt.service -> rmt-server.service
  rmt-migration.service -> rmt-server-migration.service
  See: https://github.com/SUSE/rmt/pull/159
* Mon May  7 2018 tmuntaner@suse.com
- RMT server binds to 127.0.0.1, not 0.0.0.0
  See: https://github.com/SUSE/rmt/pull/158
* Mon May  7 2018 skotov@suse.com
- Lockfile handling with File#flock
  See: https://github.com/SUSE/rmt/pull/157
* Thu May  3 2018 skotov@suse.com
- Added lockfile feature for mirror, sync & import commands
* Thu May  3 2018 tmuntaner@suse.com
- Removed ability to change user/group through configuration (GH-144)
  See: https://github.com/SUSE/rmt/pull/154
* Thu Apr 26 2018 tmuntaner@suse.com
- Added supportconfig plugin
  See: https://github.com/SUSE/rmt/pull/146
- Rename organizations_products.json to organizations_products_unscoped.json (fixes bsc#1088687)
  See: https://github.com/SUSE/rmt/pull/151
- Improved log formatting in journald
  See: https://github.com/SUSE/rmt/pull/145
* Wed Apr 25 2018 tmuntaner@suse.com
- version 0.0.7
- Fixed offline repository sync with usb (bsc#1089038)
  See: https://github.com/SUSE/rmt/pull/147
- Removed unique index for uuid in HwInfo table
  See: https://github.com/SUSE/rmt/pull/142
- "rmt-cli products enable ..." enables recommended extensions in SLE 15
  See: https://github.com/SUSE/rmt/pull/141
- Added RMT header in requests for Connect API
  See: https://github.com/SUSE/rmt/pull/139
* Thu Apr 19 2018 skotov@suse.com
- version 0.0.6
- storing hardware info
  https://github.com/SUSE/rmt/pull/138
* Mon Apr  9 2018 tmuntaner@suse.com
- Only enable free modules in migrations for SLE 15
  https://github.com/SUSE/rmt/pull/132
* Mon Apr  9 2018 ikapelyukhin@suse.com
- version 0.0.5
- Allow access to the API only via HTTPS, add directories to store SSL
  keys & certificates, add clientSetup4RMT.sh script
  https://github.com/SUSE/rmt/pull/122
* Fri Apr  6 2018 hschmidt@suse.com
- Add the offline migration endpoint for upgrading major SLES versions.
  https://github.com/SUSE/rmt/pull/121
- Use the recommended systemd service type ("simple" instead of
  "forking").
  https://github.com/SUSE/rmt/pull/129
- Don't create a local licenses directory if the repo has no licenses.
  Closes bsc#1087707.
  https://github.com/SUSE/rmt/pull/126
- Don't allow duplicate activations to exist in the DB.
  https://github.com/SUSE/rmt/pull/119
* Fri Mar 23 2018 hschmidt@suse.com
- Version 0.0.4
- Fix nginx config to point to correct root location
  See: https://github.com/SUSE/rmt/issues/113
- Add message to help output about collecting feedback from users
- Only allow one activation to exist for a given system-service
  combination.
- Update loofah and rails-html-sanitizer gems due to CVEs.
- Add proper foreign key constraints where applicable.
* Thu Feb 22 2018 tschmidt@suse.com
- Do not build for s390 (bsc#1082150)
* Fri Feb 16 2018 tmuntaner@suse.com
- Use correct service for systemd timers
* Fri Feb 16 2018 tschmidt@suse.com
- RMT on SLE12 also uses ruby 2.5
  - Removed use-ruby-2.4-in-rails.patch and use-ruby-2.4-in-rmt-cli.patch as
    they are no longer needed.
* Wed Feb 14 2018 tmuntaner@suse.com
- Fixed systemd timers for SLES 12 and Leap
* Mon Feb 12 2018 tmuntaner@suse.com
- version 0.0.3
- Added nginx integration
- Added systemd timers for rmt-server-sync and rmt-server-mirror
- Added custom repository integration
* Wed Jan 24 2018 ikapelyukhin@suse.com
- version 0.0.2
- Use cached metadata when possible (bsc#1066669)
* Sat Dec 16 2017 bwiedemann@suse.com
- Dont package build logs to make build reproducible
* Wed Dec  6 2017 dimstar@opensuse.org
- Exclude Build for i586: does not build and is not supported on
  32bit intel archs.
* Thu Nov 30 2017 tschmidt@suse.com
- Change package name to `rmt-server` to not conflict with the unix tool `rmt`
* Mon Oct 16 2017 ikapelyukhin@suse.com
- Update summary and description
- Fix 'env-script-interpreter' rpmlint error
- Ignore 'env-script-interpreter' for bundled scripts
- Remove leftover .keep files
* Thu Oct 12 2017 jengelh@inai.de
- Replace %%__-type macro indirections.
- Do not ignore errors from useradd/groupadd.
- Avoid running fdupes over partition boundaries.
- Compact description, find-delete calls and %%systemd_* calls.
* Tue Jun  6 2017 ikapelyukhin@suse.com
- Initial version 0.0.1
